# Generated by Django 2.2.10 on 2020-03-26 10:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("zgw_consumers", "0004_auto_20200113_1728"),
    ]

    operations = [
        migrations.AddField(
            model_name="service",
            name="auth_type",
            field=models.CharField(
                choices=[
                    ("no_auth", "No authorization"),
                    ("token", "Token"),
                    ("jwt", "JWT"),
                ],
                default="jwt",
                max_length=20,
                verbose_name="authorization type",
            ),
        ),
        migrations.AddField(
            model_name="service",
            name="header_key",
            field=models.CharField(
                blank=True, max_length=100, verbose_name="header key"
            ),
        ),
        migrations.AddField(
            model_name="service",
            name="header_value",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="header value"
            ),
        ),
        migrations.AddField(
            model_name="service",
            name="oas",
            field=models.URLField(
                default="",
                help_text="Path to OAS yaml file",
                max_length=255,
                verbose_name="OAS",
            ),
            preserve_default=False,
        ),
    ]
