# Generated by Django 2.2.1 on 2019-05-14 07:40

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Service",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("label", models.CharField(max_length=100, verbose_name="label")),
                (
                    "api_type",
                    models.CharField(
                        choices=[
                            ("ac", "AC (Authorizations)"),
                            ("nrc", "NRC (Notifications)"),
                            ("zrc", "ZRC (Zaken)"),
                            ("ztc", "ZTC (Zaaktypen)"),
                            ("drc", "DRC (Informatieobjecten"),
                            ("brc", "BRC (Besluiten)"),
                            ("orc", "ORC (Overige)"),
                        ],
                        max_length=20,
                        verbose_name="type",
                    ),
                ),
                (
                    "api_root",
                    models.CharField(
                        max_length=255, unique=True, verbose_name="api root url"
                    ),
                ),
                (
                    "extra",
                    django.contrib.postgres.fields.jsonb.JSONField(
                        default=dict,
                        help_text="Extra configuration that's service-specific",
                        verbose_name="extra configuration",
                    ),
                ),
                ("client_id", models.CharField(blank=True, max_length=255)),
                ("secret", models.CharField(blank=True, max_length=255)),
            ],
            options={"verbose_name": "service", "verbose_name_plural": "services"},
        )
    ]
