# Generated by Django 2.2.10 on 2020-04-01 08:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("zgw_consumers", "0008_auto_20200331_1400")]

    operations = [
        migrations.AddField(
            model_name="service",
            name="user_id",
            field=models.CharField(
                blank=True,
                help_text="User ID to use for the audit trail. Although these external API credentials are typically used bythis API itself instead of a user, the user ID is required.",
                max_length=255,
                verbose_name="user ID",
            ),
        ),
        migrations.AddField(
            model_name="service",
            name="user_representation",
            field=models.CharField(
                blank=True,
                help_text="Human readable representation of the user.",
                max_length=255,
                verbose_name="user representation",
            ),
        ),
    ]
